@@ -1,6 +1,8 @@
+from __future__ import annotations
+
 import re
 from copy import copy
-from typing import Any, Callable, Dict, List, Optional, Pattern, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Pattern, Tuple, Union, Literal
 
 from chocs.http.http_error import NotFoundError
 from chocs.http.http_method import HttpMethod
@@ -48,7 +50,7 @@ class Route:
             re.I | re.M,
         )
 
-    def match(self, uri: str) -> Union[bool, "Route"]:
+    def match(self, uri: str) -> Union[Literal[False], "Route"]:
         matches = self.pattern.findall(uri)
         if not matches:
             return False
@@ -61,6 +63,7 @@ class Route:
 
         route = copy(self)
         match_index = 0
+        route._parameters = {}
         for value in matches:
             route._parameters[self._parameters_names[match_index]] = parse_qs_value(value)
             match_index += 1
@@ -89,6 +92,17 @@ class Route:
 
         return default
 
+    def __copy__(self) -> Route:
+        new_copy = Route.__new__(Route)
+        new_copy.route = self.route
+        new_copy._parameters_names = self._parameters_names
+        new_copy._pattern = self._pattern
+        new_copy._parameters = {key: value for key, value in self._parameters.items()}
+        new_copy.is_wildcard = self.is_wildcard
+        new_copy.attributes = {key: value for key, value in self.attributes.items()}
+
+        return new_copy
+
 
 class Router:
     def __init__(self):
@@ -113,7 +127,7 @@ class Router:
     @staticmethod
     def _normalise_methods(methods: Union[str, HttpMethod, List[Union[str, HttpMethod]]]) -> List[HttpMethod]:
         if methods == "*":
-            methods = [method for method in HttpMethod]
+            methods = list(HttpMethod)
         elif isinstance(methods, HttpMethod):
             methods = [methods]
         else:
@@ -129,8 +143,9 @@ class Router:
             raise NotFoundError(f"Could not match any resource matching {method} {uri} uri")
 
         for route in self._routes[method]:
-            if route[0].match(uri):
-                return route
+            match = route[0].match(uri)
+            if match:
+                return match, route[1]
 
         raise NotFoundError(f"Could not match any resource matching {method} {uri} uri")
 
